Simple environment for automated tests
======================================

NOTICE: `data`, `containers` and `hooks.d` directories are synchronized from "project" directory in Harbor module.
WARNING: THIS IS A TEMPLATE ENVIRONMENT. EACH TEST SHOULD HAVE IT COPIED TO "current_test_env" directory and used there.